@@ -15,11 +15,8 @@ class Algo(ABC):
 
         Returns:
             A model that can be used for predictions.
-
-        Raises:
-            NotImplementedError: no implementation found in derived class.
         """
-        raise NotImplementedError
+        pass
 
     @abstractmethod
     def save(self, filename):
@@ -31,9 +28,6 @@ class Algo(ABC):
 
         Returns:
             None.
-
-        Raises:
-            NotImplementedError: no implementation found in derived class.
         """
-        raise NotImplementedError
+        pass
 
