@@ -17,6 +17,6 @@ def test_algo(algo, output_dir, timeout = 100, nan_fraction = 0.1):
         None.
     """
     if isinstance(algo, TabularClassifier)  or isinstance(algo, TabularRegressor):
-        test_tabular(algo, output_dir, timeout, nan_fraction)
+        return test_tabular(algo, output_dir, timeout, nan_fraction)
     else:
         raise TestError('invalid algo class')
