@@ -77,6 +77,8 @@ def load_tabular_data(algo, nan_fraction = 0.1):
     return (X, y, X_metatypes, y_metatypes)
 
 def test_tabular(algo, output_dir, timeout, nan_fraction):
+    output = dict()
+
     input_metatypes = algo.input_metatypes()
     if not isinstance(input_metatypes, set) or not input_metatypes:
         raise TestError('input_metatypes must be a non-empty set')
@@ -85,18 +87,24 @@ def test_tabular(algo, output_dir, timeout, nan_fraction):
         if not is_input_metatype(metatype):
             raise TestError('invalid input metatype')
 
+    output['input_metatypes'] = sorted(list(input_metatypes))
+
     dimensionality = algo.dimensionality()
     if not is_dimensionality(dimensionality, strict = True):
         raise TestError('invalid dimensionality')
 
+    output['dimensionality'] = dimensionality
+
     if isinstance(algo, TabularClassifier):
         target_metatype = algo.target_metatype()
         if not is_classification_metatype(target_metatype):
             raise TestError('invalid classification metatype')
 
+        output['target_metatype'] = target_metatype
+
         metric = get_metric('accuracy')
     else:
-        metric = get_metric('mean_absolute_error')
+        metric = get_metric('mean_squared_error')
 
     X, y, X_metatypes, y_metatypes = load_tabular_data(algo, nan_fraction)
 
@@ -117,9 +125,11 @@ def test_tabular(algo, output_dir, timeout, nan_fraction):
     if list(pred.index) != list(X.index):
         raise TestError('prediction index must equal X index')
 
+    prediction_methods = ['predict']
+
     if isinstance(algo, TabularClassifier):
         for prediction_method in ('predict_proba', 'decision_function'):
-            if hasattr(algo, prediction_method):
+            try:
                 pred_prediction_method = getattr(algo, prediction_method)(X)
                 if algo.dimensionality() == Dimensionality.UNIVARIATE:
                     pred_prediction_method = [pred_prediction_method]
@@ -127,6 +137,12 @@ def test_tabular(algo, output_dir, timeout, nan_fraction):
                 for ppm, col in zip(pred_prediction_method, y):
                     _check_prediction(prediction_method, ppm, X, y[col], pred[col])
 
+                prediction_methods.append(prediction_method)
+            except NotImplementedError:
+                pass
+
+    output['prediction_methods'] = sorted(prediction_methods)
+
     if output_dir is not None:
         filename = os.path.join(output_dir, str(uuid.uuid4()) + '.mdl')
         algo.save(filename)
@@ -140,6 +156,7 @@ def test_tabular(algo, output_dir, timeout, nan_fraction):
         os.remove(filename)
 
     print(f'TESTING DONE: {type(algo).__name__}')
+    return output
 
 def _check_prediction(prediction_method, ppm, X, y, pred):
     if not isinstance(ppm, pd.DataFrame):
